@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2025 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
-#ifndef FILTERLnotesTEST_H
-#define FILTERLnotesTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -20,5 +19,3 @@ private Q_SLOTS:
     void canNotImportDataEmptyPath();
     void canNotImportDataUnknowPath();
 };
-
-#endif // FILTERLnotesTEST_H
